;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;    GENERAL DEFINITIONS    ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;breeds are types of agents with specific properties
breed[ buildings building ]
breed[ households household ] ;in this code, households are apartments are contained in the same agent. A household has properties that belong to a human, such as values or ownership of a heat technology, and also physical properties, such as insulation level.
breed[ Htechs Htech] ;heat technologies, such as a natural gas boiler, CHP, aerial heatpump, geothermal heatpump or radiator.

globals[ ;global variables do not belong to individual agents. They are present in the "world" or "environment" and can be accessed anywhere in the code.

  ;Time related variables
  time ;years elapsed since the beginning of the simulation
  maximum-simulated-years ;number of years that will be simulated

  years-before-investing ;indicates the year from which households can make their first investment

  ;Thresholds used to activate social households
  SOCIAL-I ;threshold that indicates the average insulation level of the neighborhood that, when met, would trigger social agents to consider making an investment.
  SOCIAL-H ;threshold that indicates the number or fraction of heat technologies different than a natural gas boiler, when met, would trigger social agents to consider making an investment.
  SOCIAL-threshold ;threshold that indicates the fraction of peers that need to have either better insulation or a different technology before a social agent reacts

  ;Key performance indicators (KPIs)
  ;Heating expenses
  total-expenses ;KPI
  total-yearly-expenses ;while not a KPI, useful to visualize data
  ;Natural gas
  total-gas ;KPI
  total-yearly-gas ;while not a KPI, useful to visualize data

  ;Number of heat technologies of each type. Each variable will be the number of heat technologies that are present in the neighborhood of one given type.
  NGboiler
  CHP
  radiators
  HPair
  Hpgeo

  ;insulation levels
  in-low
  in-med
  in-hgh
  capacity-insulation-level-3

  ;fuel prices
  all-gas-price
  gas-price
  all-ele-price
  ele-price

  ;Htech specifications
  Htech-sizeGroups
  Htech-name
  Htech-Esource
  Htech-heat
  Htech-electricity
  Htech-nH
  Htech-nE
  Htech-CapEx
  Htech-OpEx
  Htech-lifetime
  newCHPOpEx
  Htech-NGuse
  Htech-eleuse

  ;insulation plans
  inPlan-options
  inPlan-newinsulation-level
  inPlan-CapEx
  inPlan-Capacity
  inPlan-Demand

  numAp ;number of apartments in each building

  numBuild ;number of buildings

]


buildings-own[
  householdsOwned ]

households-own[

  ;identity
  buildingOwner
  hTechBought

  ;characteristics of household
  AAI
  HRZ
  ESF
  invest?

  ;heat demand and consumption
  Hdemand
  Hconsumed/h
  insulation-level-historical
  htechs-historical-name
  htechs-historical-self
  htechs-historical-capacity

  ;KPIs for a single household
  NGconsumed
  NGconsumed-yearly
  cashflow
  expenses-yearly

  ;apartment characteristics
  insulation-level

  ;references
  peers-with-better-insulation
  peers-with-other-htech
  peers-with-other-insulation-or-technology

  ;variables to prepare and select investments
  cba-3-cost
  cba-2-cost
  cba-1-cost

  cba-3-gas
  cba-2-gas
  cba-1-gas

  cba-capex-opex-3
  cba-capex-opex-2
  cba-capex-opex-1

  cba-option
  cba-position
  cba-insulation-level
  cba-newHtech

]



hTechs-own[

  ;identity
  householdOwner
  building-of-apartment
  name
  age

  ;characteristics
  nH
  nE
  CapEx
  OpEx
  Capacity
  e-source

  ;operation
  Active
  Production
  e-sourceUse
  NGconsumed/h
  e-sourceCost

  ;cummulative
  ProductionAc
  e-sourceUseAc
  e-sourceCostAc
  OpExAc
  NGconsumed

]



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;     SETUP     ;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



to setup

  clear-all

  setup-expVariables
  setup-environment
  setup-buildings
  setup-households
  setup-boilers


  reset-ticks
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;   SET-UP EXPERIMENTAL VARIABLES  ;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-expVariables

  set capacity-insulation-level-3 15 ;assummed needed capacity for htechs in households with insulation-level=3
  set numBuild 2 ;number of buildings in the simulation
  set numAp 12 ;number of apartments in the model
  set maximum-simulated-years 20 ;number of years in the simulation
  set SOCIAL-I .6
  set SOCIAL-H .6
  set SOCIAL-threshold .3

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;     SET-UP ENVIRONMENT    ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-environment
  set time 0
  set years-before-investing 5
  setup-Eprices
  setup-Htech
  setup-insulationPlans
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;       SET-UP E-PRICES     ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-Eprices
  set all-gas-price [.08] ;in Euro/kWh, from Eurostat. Current values for 2016
  set all-ele-price [.16] ;electricity price in EUR/kWh, from Eurostat. Current values for 2016
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;       SET-UP H-TECH      ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;need to check sources of this data. Somewhere I have them printed and also reported in my notebook

to setup-Htech
  set Htech-sizeGroups  [0 1 2 3 ] ;sizes are "0"=<25kw,"1"= 25-100kw,"2"= 101-250kw,"3"= 250-350kw. In the simulations reported in this paper, we only use the smallest size of technologies.
  set Htech-name        [["CHP" "FullyE" "HPair" "HPgeo"] ["CHP" "FullyE"] ["CHP" "FullyE"] ["CHP" "FullyE"]]
  set Htech-Esource     [["gas" "electricity" "electricity" "electricity" "gas"] ["gas" "electricity"] ["gas" "electricity"] ["gas" "electricity"]] ;energy source that a technology uses
  set Htech-NGuse       [[1 0 0 0] [1 0] [1 0] [1 0]] ;dummy variable to indicate if a technology uses natural gas. Useful later in the code.
  set Htech-eleuse      [[0 1 1 1] [0 1] [0 1] [0 1]] ;dummy variable to indicate if a technology uses electricity. Useful later in the code.
  set Htech-heat        [[1 1 1 1] [1 1] [1 1] [1 1]] ;dummy variable to indicate if a technology produces heat. Useful later in the code.
  set Htech-electricity [[1 0 0 0] [1 0] [1 0] [1 0]] ;dummy variable to indicate if a technology produces electricity. Useful later in the code.
  set Htech-nH          [[.60 1 2.6 3.3] [.60 1] [.60] [.60]] ;thermal efficiency of heat technologies
  set Htech-nE          [[.28 0 0 0] [.32 0] [.32 0] [.32 0]] ;electrical efficiency of heat technologies
  set Htech-CapEx       [[2100 300 1130 1675] [1341 300] [732 300] [393 300]] ;EUR/kW.  Capital costs of heat technologies.   300 assumed based on online prices of wall radiators
  set Htech-OpEx        [[42 10 22.6 33.5] [26.8 10] [14.6 10] [7.86 10]] ;EUR/kW-year. Operation costs of heat technologies. 2% for CHP from literature, assumed 2% for air pumps
  set Htech-lifetime    [[20 30 20 20] [20 30] [20 30] [20 30]]; years - assumed for FullyE: https://www.atdhomeinspection.com/advice/average-product-life/
  ;lifetime of boilers is an assumption

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;    SET-UP INSULATION PLANS   ;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-insulationPlans
  set inPlan-options  [0 1] ;These numbers indicate the position of an insulation level in the lists below (explanation continues in the lines below).
  ;Options are "0" for dwellings with insulation-level = 3 and "1" for dwellings with insulation-level = 2, no options for insulation-level = 1.
  ;For example, in inPlan-new_insulation-level, position 0 of the list contains numbers [2 and 1],
  ;which means that an apartment with an insulation level of 3 can improve its insulation to either 2 (medium) or 1 (high).
  set inPlan-newinsulation-level    [[2  1] [1]]
  set inPlan-CapEx    [[5500 10000] [6000]]
  set inPlan-Capacity [[8 5] [5]]
  set inPlan-Demand   [25000 10000 5000]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;      SET-UP BUILDINGS     ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-buildings

  create-buildings numBuild [
    setxy random-xcor random-ycor
    set shape "square 2"
    set size 5
]


end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;      SET-UP HOUSEHOLDS    ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-households

  ask buildings [

    hatch-households numAp[

      set size 1
      set insulation-level-historical [] ;will store every insulation level that the household has had, to make it easier for the model user to access this information at any time in the simulation.
      set htechs-historical-name []      ;will store the name of every heat technology that the household has had, to make it easier for the model user to access this information at any time in the simulation.
      set htechs-historical-self []      ;will store the identifier of every heat technology that the household has had, to make it easier for the model user to access this information at any time in the simulation.
      set htechs-historical-capacity []  ;will store the capacity of heat technology level that the household has had, to make it easier for the model user to access this information at any time in the simulation.
      set cba-option -1
      set cba-position -1 ;to ensure that CHPs are not chosen while no analysis has been made
      set cba-insulation-level "No change"
      set cba-newhtech "No change"
      set buildingOwner myself
      set hTechBought []
      set insulation-level 3
      set HRZ all-HRZ
      set ESF 0
      set AAI 0
      set invest? years-before-investing
      ]

    set householdsOwned households with [buildingOwner = myself]
  ]

  ;to represent the households that can make compared investments
  ask n-of (AAI% * count households) households [
    set AAI 1]

  ;sets the population of households depending on their ESF values
  let number-of-households count households

  if popESF = 1[
    ask n-of (number-of-households / 3) households with [ESF = 0] [
      set ESF "Environmental"]
    ask n-of (number-of-households / 3) households with [ESF = 0] [
      set ESF "Social"]
    ask n-of (number-of-households / 3) households with [ESF = 0] [
      set ESF "Financial"]  ]

  if popESF = 2[
    ask n-of (number-of-households / 2) households with [ESF = 0] [
      set ESF "Environmental"]
    ask n-of (number-of-households / 4) households with [ESF = 0] [
      set ESF "Social"]
    ask n-of (number-of-households / 4) households with [ESF = 0] [
      set ESF "Financial"]  ]

  if popESF = 3[
    ask n-of (number-of-households / 4) households with [ESF = 0] [
      set ESF "Environmental"]
    ask n-of (number-of-households / 2) households with [ESF = 0] [
      set ESF "Social"]
    ask n-of (number-of-households / 4) households with [ESF = 0] [
      set ESF "Financial"]  ]

  if popESF = 4[
    ask n-of (number-of-households / 4) households with [ESF = 0] [
      set ESF "Environmental"]
    ask n-of (number-of-households / 4) households with [ESF = 0] [
      set ESF "Social"]
    ask n-of (number-of-households / 2) households with [ESF = 0] [
      set ESF "Financial"]  ]

  if popESF = 5[
    ask households [
      set ESF "Environmental"]  ]

  if popESF = 6[
    ask households [
      set ESF "Social"]  ]

  if popESF = 7[
    ask households [
      set ESF "Financial"]  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;        SET-UP HTECH       ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup-boilers

  ask households [
    hatch-hTechs 1 [
      set building-of-apartment [buildingowner] of myself
      set householdOwner myself
      set name "NG-boiler"
      set age 10
      set e-source "gas"
      set nH 1
      set nE 0
      set CapEx 559 ;;EUR/kW based on literature, up to 25kW
      set OpEx 11.18   ;EUR/kW-year - 2% for boilers from literature, for 15kWh
      set Capacity capacity-insulation-level-3
      set Active 1]
      set hTechBought [self] of hTechs with [householdOwner = myself]
      set ngconsumed 0]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;     TO GO     ;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to go

  update-environment
  households-demandHeat
  households-prepare-investments
  households-select-investment
  households-invest
  state

  if ticks = ( maximum-simulated-years ) [stop]
  tick

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;    UPDATE ENVIRONMENT     ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to update-environment
  set time time + 1
  update-years-before-investing
  change-energy-and-Htech-prices-and-efficiency
  htech-age-and-generate-OpEx-yearly-costs
  households-pay-OpEx-costs
  households-update-references

end



to update-years-before-investing
  ;every year, agents get closer to the time when they can invest again.
  ;The purpose of having this number is to represent how, after making an investment, people would wait before making another one. They need to gather financial capital again.
  ask households [
    set invest? invest? - 1]

end


to change-energy-and-Htech-prices-and-efficiency
  ;energy retail prices change, depending on the scenarios that are being modelled.
  ;in the all-gas-price and all-ele-price, prices over the years are stored and can be consulted while using the model.

  set all-gas-price lput (last all-gas-price * (1 + dgp)) all-gas-price
  set all-ele-price lput (last all-ele-price * (1 + dep)) all-ele-price

  ;after the previous variables, which store all the prices, are updated, the latest addition is retrieved and used as the current price during that year.
  set gas-price item (time - 1) all-gas-price
  set ele-price item (time - 1) all-ele-price

  ;cost and efficiency of Htech changes - microCHPs costs drop, as expected in the literature.
  let old-HtechCapEx item 0 Htech-CapEx
  set Htech-CapEx replace-item 0 Htech-CapEx (replace-item 0 old-HtechCapEx (item 0 old-HtechCapEx * .98))

  let old-Htech-OpEx item 0 Htech-OpEx
  set Htech-OpEx replace-item 0 Htech-OpEx (replace-item 0 old-Htech-OpEx (item 0 old-Htech-OpEx * .98))
end


to htech-age-and-generate-OpEx-yearly-costs
  ;technologies age
  ask htechs [
      set age age + 1]
  ;accumulation of OpEx over the years, stored in the technology itself
  ask htechs [
    set OpExAc OpExAc + (OpEx * Capacity)]
end

to households-pay-OpEx-costs
  ;households pay for the OpEx costs of the technology that they own
  ;the code works because each household has only one heat technology at a time
  ;if it were possible in the model to have more than one technology at a time, the code would have to be modified
  ask households [
    let OpEx1 [OpEx] of one-of htechs with [householdowner = myself]
    let Capa1 [Capacity] of one-of htechs with [householdowner = myself]
    set cashflow cashflow - (OpEx1 * Capa1)
    set expenses-yearly (OpEx1 * Capa1)]
end

to households-update-references
  ask households [

    set peers-with-better-insulation count households with [insulation-level < ([insulation-level] of myself)]

    let myhtech [name] of htechs with [householdOwner = myself]
    set peers-with-other-htech count htechs with [name != one-of myhtech]

    let htechs-different htechs with [name != one-of myhtech]
    let households-different-htechs households with [htechbought != myhtech]
    ;calculates the number of households who either have better insulation or a different technology than themselves
    set peers-with-other-insulation-or-technology count households with [insulation-level < ([insulation-level] of myself) or (member? one-of htechbought htechs-different)]
  ]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;  HOUSEHOLDS DEMAND HEAT   ;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to households-demandHeat

  ;this is how all households demand heat
  ;values are retrieved from a global variable that indicates how much heat would be demanded by an apartment with a given level of insulation
  ask households with [insulation-level = 3][
    set Hdemand item 0 inPlan-Demand]
  ask households with [insulation-level = 2][
    set Hdemand item 1 inPlan-Demand]
  ask households with [insulation-level = 1][
    set Hdemand item 2 inPlan-Demand]

  ;households use their technologies to produce heat
  ask households [
;might want to get rid of the "active" variable later
    ask hTechs with [householdOwner = myself and active = 1] [ ;households ask their active technology to generate heat
      ifelse ([Hdemand] of myself) > (Capacity * 8760) [       ;if the demand is bigger than the technology's capacity
        set Production (Capacity * 8760)][                     ;then it will only produce the maximum capacity of the technology
        ifelse [Hdemand] of myself > 0 [                       ;if the demand is not bigger than the capacity and if it is bigger than zero
          set Production ([Hdemand] of myself)][               ;the technology will produce the entire demand
          set Production 0]]                                   ;if the demand is not bigger than zero then no production will occur
                                                               ;the model is written in such a way that no negative demand is expected
      ;heat generation consumes fuel
      set e-sourceUse (Production / nH)   ;calculates how much fuel an hTech is using using the technology's thermal efficiency

      ;fuel costs money
      if e-source = "gas" [
        set e-sourceCost e-sourceUse * gas-price ;if the source is gas, then cost of source is updated according to gas price
        set NGconsumed NGconsumed + e-sourceUse  ;and the techology's gas consumption is updated
        ask [self] of householdOwner [           ;the household's gas consumption is also updated
          set NGconsumed NGconsumed + [e-sourceUse] of myself
          set NGconsumed-yearly [e-sourceUse] of myself]]
      if e-source = "electricity"[               ;if the source is electricity, then cost of source is updated according to electricity price
        set e-sourceCost e-sourceUse * ele-price
        ask [self] of householdOwner [
          set NGconsumed-yearly 0]]

      ;cummulative properties of the heat technology are updated
      set ProductionAc   ProductionAc   + Production
      set e-sourceUseAc  e-sourceUseAc  + e-sourceUse
      set e-sourceCostAc e-sourceCostAc + e-sourceCost

      ;cummulative and yearly expenses of the household are also updated
      ask [self] of householdowner [
        set cashflow cashflow - [e-sourceCost] of myself
        set expenses-yearly expenses-yearly + [e-sourceCost] of myself]]]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;  HOUSEHOLDS PREPARE INVESTMENTS   ;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to households-prepare-investments

  ask households [

    if invest? <= 0 [ ;if households are ready to make an investment, because enough time has elapsed since last time they made an investment
      ;households calculate input data for their assessment
      ;they calculate how much gas they would use and how much money they would spend


      ;they estimate what their total heat demand would be with different insulation-level, over the course of their time horizon
      let HRZdemand-3  item 0 inPlan-Demand * HRZ
      let HRZdemand-2  item 1 inPlan-Demand * HRZ
      let HRZdemand-1  item 2 inPlan-Demand * HRZ


      ;they estimate gas consumed if they had different insulation levels
      ;with each different technology that is available in the market at that exact moment
      let gas-3     (map [i -> (HRZdemand-3 / i)] item 0 Htech-nH) ;energy needed to produce heat considering efficiency of each technology
      set cba-3-gas (map * gas-3  item 0 Htech-NGuse) ;multiplying the energy needed by whether the technology uses gas or not
      let gas-2     (map [i -> (HRZdemand-2 / i)] item 0 Htech-nH)
      set cba-2-gas (map * gas-2  item 0 Htech-NGuse)
      let gas-1     (map [i -> (HRZdemand-1 / i)] item 0 Htech-nH)
      set cba-1-gas (map * gas-1  item 0 Htech-NGuse)

      ;until now, the current state had not been considered, gas still needs to be added.
      ;gas that would be consumed if technology is not changed. added to the list.
      ifelse [e-source] of one-of htechs with [householdOwner = myself and active = 1] = "gas" [
        let my-nH [nH] of one-of htechs  with [householdOwner = myself and active = 1]
        set cba-3-gas lput ((HRZdemand-3 / my-nH)) cba-3-gas
        set cba-2-gas lput ((HRZdemand-2 / my-nH)) cba-2-gas
        set cba-1-gas lput ((HRZdemand-1 / my-nH)) cba-1-gas
        ][
        set cba-3-gas lput 0 cba-3-gas
        set cba-2-gas lput 0 cba-2-gas
        set cba-1-gas lput 0 cba-1-gas]

      ;up to this point of the code, households end up with three variables (cba-3-gas, cba-2-gas and cba-1-gas, each of which is a list of gas that
      ;would be consumed with each technology in the market, and then with the current option being the last one in the list


      ;next step is to estimate how much each option would cost
      ;starting with estimating costs opex and capex

      ;these estimates consider that the insulation level does not change. There is a different calculation for each
      ;insulation level because this changes the capacity of the technology that would be bought.
      ;the result is a single variable, which is a list of the capex and opex of each technology in the market
      ;the list also includes the costs of the current technology (no change)

      ;first, if the apartment were to have a insulation-level = 3
      let cba-capex-bef-3   map [i -> i * capacity-insulation-level-3] item 0 Htech-CapEx    ;list of CapEx from technologies in the market
      let cba-capex-3       lput 0 cba-capex-bef-3  ;if they keep their current technology, they don't have CapEx costs
      let cba-opex-bef-3    map [i -> i * HRZ * capacity-insulation-level-3]item 0 Htech-OpEx ;list of OpEx from technologies in the market
      let cba-opex-3        lput (([OpEx] of one-of htechs with [householdOwner = myself and active = 1]) * HRZ * capacity-insulation-level-3) cba-opex-bef-3 ;if they keep their current technology, they also have OpEx costs
      set cba-capex-opex-3 (map + cba-capex-3 cba-opex-3) ;this is the cost of buying the technology and operation costs excluding fuel, for all technologies available in the market and also for the current technology

      ;second, if the apartment were to have a insulation-level = 2
      let cba-capex-bef-2   map [i -> i * item 0 item 0 inPlan-Capacity] item 0 Htech-CapEx    ;list of CapEx from technologies in the market
      let cba-capex-2       lput 0 cba-capex-bef-2  ;if they keep their current technology, they don't have CapEx costs
      let cba-opex-bef-2    map [i -> i * HRZ * item 0 item 0 inPlan-Capacity] item 0 Htech-OpEx ;list of OpEx from technologies in the market
      let cba-opex-2        lput (([OpEx] of one-of htechs with [householdOwner = myself and active = 1]) * HRZ * item 0 item 0 inPlan-Capacity) cba-opex-bef-2 ;if they keep their current technology, they also have OpEx costs
      set cba-capex-opex-2 (map + cba-capex-2 cba-opex-2) ;this is the cost of buying the technology and operation costs excluding fuel, for all technologies available in the market and also for the current technology

      ;third, if the apartment were to have a insulation-level = 1
      let cba-capex-bef-1   map [i -> i * item 1 item 0 inPlan-Capacity] item 0 Htech-CapEx    ;list of CapEx from technologies in the market
      let cba-capex-1       lput 0 cba-capex-bef-1  ;if they keep their current technology, they don't have CapEx costs
      let cba-opex-bef-1    map [i -> i * HRZ * item 1 item 0 inPlan-Capacity] item 0 Htech-OpEx ;list of OpEx from technologies in the market
      let cba-opex-1        lput (([OpEx] of one-of htechs with [householdOwner = myself and active = 1]) * HRZ * item 1 item 0 inPlan-Capacity) cba-opex-bef-1 ;if they keep their current technology, they also have OpEx costs
      set cba-capex-opex-1 (map + cba-capex-1 cba-opex-1) ;this is the cost of buying the technology and operation costs excluding fuel, for all technologies available in the market and also for the current technology

      ;fuel costs are also estimated for the technologies in the market.
      ;estimate HYPOTHETICAL fuel costs, IF INSULATION WERE DIFFERENT, IF HTECH WERE DIFFERENT
      let cba-eleCost-3     (map / ((map [i -> i * ele-price] (map [i -> i * HRZdemand-3] item 0 Htech-eleuse))) item 0 Htech-nh) ;electricity costs
      let cba-gasCost-3     (map / ((map [i -> i * gas-price] (map [i -> i * HRZdemand-3] item 0 Htech-NGuse))) item 0 Htech-nh)  ;gas costs
      let cba-fuelcost-3-1  (map + cba-eleCost-3 cba-gasCost-3) ;this is the cost of the fuel for each technology available in the market ;electricity and gas costs

      let cba-eleCost-2     (map / ((map [i -> i * ele-price] (map [i -> i * HRZdemand-2] item 0 Htech-eleuse))) item 0 Htech-nh) ;electricity costs
      let cba-gasCost-2     (map / ((map [i -> i * gas-price] (map [i -> i * HRZdemand-2] item 0 Htech-NGuse))) item 0 Htech-nh)  ;gas costs
      let cba-fuelcost-2-1  (map + cba-eleCost-2 cba-gasCost-2) ;this is the cost of the fuel for each technology available in the market ;electricity and gas costs

      let cba-eleCost-1     (map / ((map [i -> i * ele-price] (map [i -> i * HRZdemand-1] item 0 Htech-eleuse))) item 0 Htech-nh) ;electricity costs
      let cba-gasCost-1     (map / ((map [i -> i * gas-price] (map [i -> i * HRZdemand-1] item 0 Htech-NGuse))) item 0 Htech-nh)  ;gas costs
      let cba-fuelcost-1-1  (map + cba-eleCost-1 cba-gasCost-1) ;this is the cost of the fuel for each technology available in the market ;electricity and gas costs

      ;from the previous cost calculation we were still missing the current situation, so we will add it below.
      ;estimate fuel costs of current htech with current insulation
      ;add current estimate to HYPOTHETICAL estimate of fuel costs
      ;estimate total costs over HRZ by adding fuel costs to capex and opex
      if [e-source] of one-of htechs with [householdOwner = myself and active = 1] = "gas" [
        let zero-fuel-3    (HRZdemand-3 / ([nh] of one-of htechs with [householdOwner = myself and active = 1])) * gas-price ;fuel that the current technology would consume over the time horizon
        let cba-fuelcost-3  lput zero-fuel-3 cba-fuelcost-3-1      ;adding the estimated fuel to the variable with all the estimates for fuel
        set cba-3-cost     (map + cba-capex-opex-3 cba-fuelcost-3) ;adding the cost of fuel and the cost of buying and operating the technologies

        let zero-fuel-2    (HRZdemand-2 / ([nh] of one-of htechs with [householdOwner = myself and active = 1])) * gas-price ;fuel that the current technology would consume over the time horizon
        let cba-fuelcost-2  lput zero-fuel-2 cba-fuelcost-2-1      ;adding the estimated fuel to the variable with all the estimates for fuel
        set cba-2-cost     (map + cba-capex-opex-2 cba-fuelcost-2) ;adding the cost of fuel and the cost of buying and operating the technologies

        let zero-fuel-1    (HRZdemand-1 / ([nh] of one-of htechs with [householdOwner = myself and active = 1])) * gas-price ;fuel that the current technology would consume over the time horizon
        let cba-fuelcost-1  lput zero-fuel-1 cba-fuelcost-1-1       ;adding the estimated fuel to the variable with all the estimates for fuel
        set cba-1-cost     (map + cba-capex-opex-1 cba-fuelcost-1)] ;adding the cost of fuel and the cost of buying and operating the technologies

      if [e-source] of one-of htechs with [householdOwner = myself and active = 1] = "electricity" [
        let zero-fuel-3    (HRZdemand-3 / ([nh] of one-of htechs with [householdOwner = myself and active = 1])) * ele-price ;fuel that the current technology would consume over the time horizon
        let cba-fuelcost-3  lput zero-fuel-3 cba-fuelcost-3-1      ;adding the estimated fuel to the variable with all the estimates for fuel
        set cba-3-cost     (map + cba-capex-opex-3 cba-fuelcost-3) ;adding the cost of fuel and the cost of buying and operating the technologies

        let zero-fuel-2    (HRZdemand-2 / ([nh] of one-of htechs with [householdOwner = myself and active = 1])) * ele-price ;fuel that the current technology would consume over the time horizon
        let cba-fuelcost-2  lput zero-fuel-2 cba-fuelcost-2-1      ;adding the estimated fuel to the variable with all the estimates for fuel
        set cba-2-cost     (map + cba-capex-opex-2 cba-fuelcost-2) ;adding the cost of fuel and the cost of buying and operating the technologies

        let zero-fuel-1    (HRZdemand-1 / ([nh] of one-of htechs with [householdOwner = myself and active = 1])) * ele-price ;fuel that the current technology would consume over the time horizon
        let cba-fuelcost-1  lput zero-fuel-1 cba-fuelcost-1-1       ;adding the estimated fuel to the variable with all the estimates for fuel
        set cba-1-cost     (map + cba-capex-opex-1 cba-fuelcost-1)] ;adding the cost of fuel and the cost of buying and operating the technologies

        ;from the previous code, we imagined how much it would cost to have different levels of insulation in terms of fuel consumption and heat technologies.
        ;we did not add the cost of actually insulating to jump from a level to the next one. That is done below.
        ;add insulation costs to the total costs so they can be compared
        if insulation-level = 3 [ ;if an apartment already has an insulation level 3, it can only change its level to either 2 or 1. Therefore, if it remains with level 3, no additional costs happen
          set cba-2-cost (map [i -> i + item 0 item 0 inPlan-CapEx] cba-2-cost)
          set cba-1-cost (map [i -> i + item 1 item 0 inPlan-CapEx] cba-1-cost)]
        if insulation-level = 2 [ ;if an apartment already has an insulation level 2, it can only change its level to 1. Therefore, if it remains with level 2, no additional costs happen. It is not possible to go back to level 3.
          set cba-1-cost (map [i -> i + item 0 item 1 inPlan-CapEx] cba-1-cost)]

        ;substract electricity savings from the total cost so they can be included in comparison
        let chp-savings-3 (item 0 cba-3-gas) * (item 0 item 0 Htech-ne) * ele-price
        let chp-savings-2 (item 0 cba-2-gas) * (item 0 item 0 Htech-ne) * ele-price
        let chp-savings-1 (item 0 cba-1-gas) * (item 0 item 0 Htech-ne) * ele-price
        set cba-3-cost replace-item 0 cba-3-cost (item 0 cba-3-cost - chp-savings-3)
        set cba-2-cost replace-item 0 cba-2-cost (item 0 cba-2-cost - chp-savings-2)
        set cba-1-cost replace-item 0 cba-1-cost (item 0 cba-1-cost - chp-savings-1)]]

end




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;   HOUSEHOLDS SELECT INVESTMENTS   ;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to households-select-investment

  ask households [

    if invest? <= 0 [  ;this means that a household has not invested in its own HRZ. It prevents a household from investing during the HRZ years after it invests.

      if AAI = 1 [ ;The code below applies for households who are able to compare investments

        ;Social agents need to be activated first, to confirm that they make decisions based on the previous situation.
        if ESF = "Social" [ ;if households are socially oriented, they will act only when a certain number of households has already acted and they will select the cheapest option available to them

          ifelse peers-with-other-insulation-or-technology > (count households * SOCIAL-threshold) [
          ;ifelse (peers-with-other-htech > (count htechs * SOCIAL-H)) ;if a given fraction of households have a tecnology that is different than the agent's
                 ;or                                       ;or
                 ;(peers-with-better-insulation > (count households * SOCIAL-I)) [  ;if a fraction of households have a level of insulation that is different to their own, then they take action

            let cba-3-cost-min min cba-3-cost ;cheapest option within the level 3 insulation
            let cba-2-cost-min min cba-2-cost ;cheapest option within the level 2 insulation
            let cba-1-cost-min min cba-1-cost ;cheapest option within the level 1 insulation
            set cba-option min (list cba-3-cost-min cba-2-cost-min cba-1-cost-min) ;cheapest option from the previous three options

            if cba-option = cba-3-cost-min [
              set cba-position position cba-option cba-3-cost
              ifelse insulation-level = 3 [
                set cba-insulation-level "No change"][
                set cba-insulation-level 3]]

            if cba-option = cba-2-cost-min [
              set cba-position position cba-option cba-2-cost
              ifelse insulation-level = 2 [
                set cba-insulation-level "No change"][
                set cba-insulation-level 2]]

            if cba-option = cba-1-cost-min [
              set cba-position position cba-option cba-1-cost
              ifelse insulation-level = 1 [
                set cba-insulation-level "No change"][
                set cba-insulation-level 1]]]

          ;here ends the first part of the IFELSE procedure that describes what happens when social households do act
          ;lines below are what happens if social households do NOT act
          [set cba-insulation-level "No change"
            set cba-position -1
            set cba-newhtech "No change"]]


        if  ESF = "Environmental" [ ;if they are environmentally oriented they will select the cheapest option within the options that do not consume natural gas (or that consume the least)

          let cba-3-cost-untie (map [i -> i / 200000] cba-3-cost) ;more than one technology uses no gas. Therefore, the they are ranked according to their costs. The "200000" is only used to rank them according to their costs
          let cba-3-gas-untie  (map + cba-3-cost-untie cba-3-gas) ;the rank based on their costs is added to the gas consumption: if an option is more expensive, it will have a higher value of "cba-3-gas-untie"
          let cba-3-gas-min min cba-3-gas-untie ;the lowest value of "cba-gas-untie" is selected: from options that consume no gas, the cheapest is selected
          let cba-2-cost-untie (map [i -> i / 200000] cba-2-cost) ;same explanation than before, this time, for insulation level 2
          let cba-2-gas-untie  (map + cba-2-cost-untie cba-2-gas)
          let cba-2-gas-min min cba-2-gas-untie
          let cba-1-cost-untie (map [i -> i / 200000] cba-1-cost) ;same explanation than before, this time, for insulation level 1
          let cba-1-gas-untie  (map + cba-1-cost-untie cba-1-gas)
          let cba-1-gas-min min cba-1-gas-untie

          set cba-option min (list cba-3-gas-min cba-2-gas-min cba-1-gas-min) ;from options within the three insulation levels, the cheapest one within options that consume no gas is selected

          ;when applicable, selected insulation level is updated or a "No change" is recorded
          if cba-option = cba-3-gas-min [
            set cba-position position cba-option cba-3-gas-untie
            set cba-option item cba-position cba-3-gas
            ifelse insulation-level = 3 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 3]]

          if cba-option = cba-2-gas-min [
            set cba-position position cba-option cba-2-gas-untie
            set cba-option item cba-position cba-2-gas
            ifelse insulation-level = 2 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 2]]

          if cba-option = cba-1-gas-min [
            set cba-position position cba-option cba-1-gas-untie
            set cba-option item cba-position cba-1-gas
            ifelse insulation-level = 1 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 1]]]


        if ESF = "Financial" [ ;if households are financially oriented, they select the cheapest option

          let cba-3-cost-min min cba-3-cost  ;cheapest option within the level 3 insulation
          let cba-2-cost-min min cba-2-cost  ;cheapest option within the level 2 insulation
          let cba-1-cost-min min cba-1-cost  ;cheapest option within the level 1 insulation
          set cba-option min (list cba-3-cost-min cba-2-cost-min cba-1-cost-min) ;cheapest option from the previous three options

          if cba-option = cba-3-cost-min [
            set cba-position position cba-option cba-3-cost
            ifelse insulation-level = 3 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 3]]

          if cba-option = cba-2-cost-min [
            set cba-position position cba-option cba-2-cost
            ifelse insulation-level = 2 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 2]]

          if cba-option = cba-1-cost-min [
            set cba-position position cba-option cba-1-cost
            ifelse insulation-level = 1 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 1]]]


        ;For all househols (social, environmental and financial), when appliable, selected heat technology is updated. Otherwise, a "No change" is recorded
        if cba-position = 0 [
          set cba-newHtech "CHP"]
        if cba-position = 1 [
          set cba-newHtech "FullyE"]
        if cba-position = 2 [
          set cba-newHtech "HPair"]
        if cba-position = 3 [
          set cba-newHtech "HPgeo"]
        if cba-position = 4 [
          set cba-newHtech "No change"]]


      ;The code below applies for households who are NOT able to compare investments
      if AAI = 0 [
        if ESF = "Social" [ ;if households are socially oriented

          ifelse peers-with-other-insulation-or-technology > (count households * SOCIAL-threshold) [
          ;ifelse (peers-with-other-htech > (count htechs * SOCIAL-H)) ;if a given fraction of households have already replaced their natural gas boiler
                 ;or                                       ;or
                 ;(peers-with-better-insulation > (count households * SOCIAL-I)) [  ;if a fraction of households have already improved their insulation, then they take action

            if insulation-level = 3 [
              let cba-3-cost-min min cba-3-cost ;they can choose to do nothing, or to replace their technology and keep the same level of insulation. They choose the cheapest of these options and store it in "cba-3-cost-min"
              set cba-option min (list cba-3-cost-min item 4 cba-2-cost item 4 cba-1-cost)] ;or they can choose to keep the same technology and improve their insulation
            if insulation-level = 2 [
              let cba-2-cost-min min cba-2-cost
              set cba-option min (list cba-2-cost-min item 4 cba-1-cost)]
            if insulation-level = 1 [
              let cba-1-cost-min min cba-1-cost
              set cba-option cba-1-cost-min]

            if member? cba-option cba-3-cost [
              set cba-position position cba-option cba-3-cost
              ifelse insulation-level = 3 [
                set cba-insulation-level "No change"][
                set cba-insulation-level 3]]

            if member? cba-option cba-2-cost [
              set cba-position position cba-option cba-2-cost
              ifelse insulation-level = 2 [
                set cba-insulation-level "No change"][
                set cba-insulation-level 2]]

            if member? cba-option cba-1-cost [
              set cba-position position cba-option cba-1-cost
              ifelse insulation-level = 1 [
                set cba-insulation-level "No change"][
                set cba-insulation-level 1]]][


            set cba-insulation-level "No change"
            set cba-position -1
            set cba-newhtech "No change"]]


        if ESF = "Financial" [ ;if households have financial preference

          if insulation-level = 3 [
            let cba-3-cost-min min cba-3-cost
            set cba-option min (list cba-3-cost-min item 4 cba-2-cost item 4 cba-1-cost)]

          if insulation-level = 2 [
            let cba-2-cost-min min cba-2-cost
            set cba-option min (list cba-2-cost-min item 4 cba-1-cost)]
          if insulation-level = 1 [
            let cba-1-cost-min min cba-1-cost
            set cba-option cba-1-cost-min]

          if member? cba-option cba-3-cost [
            set cba-position position cba-option cba-3-cost
              ifelse insulation-level = 3 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 3]]

          if member? cba-option cba-2-cost [
            set cba-position position cba-option cba-2-cost
            ifelse insulation-level = 2 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 2]]

          if member? cba-option cba-1-cost [
            set cba-position position cba-option cba-1-cost
            ifelse insulation-level = 1 [
              set cba-insulation-level "No change"][
              set cba-insulation-level 1]]]


        if ESF = "Environmental" [ ;if households are evironmentally oriented

          if insulation-level = 3 [
            let cba-3-cost-untie (map [i -> i / 200000] cba-3-cost)
            let cba-3-gas-untie  (map + cba-3-cost-untie cba-3-gas)
            let cba-3-gas-min     min cba-3-gas-untie ;no emissions, lowest cost-option
            let cba-3-gas-min-position position cba-3-gas-min cba-3-gas-untie
            let cba-2-gas-adjusted item 4 cba-2-gas + item 4 cba-2-cost / 200000
            let cba-1-gas-adjusted item 4 cba-1-gas + item 4 cba-1-cost / 200000
            set cba-option min (list cba-3-gas-min cba-2-gas-adjusted cba-1-gas-adjusted)

            if member? cba-option cba-3-gas-untie [
              set cba-insulation-level "No change"
              set cba-position cba-3-gas-min-position
              set cba-option   item cba-position cba-3-gas]

            if  cba-option = cba-2-gas-adjusted [
              set cba-insulation-level 2
              set cba-position 4
              set cba-option   item 4 cba-2-gas]

            if  cba-option = cba-1-gas-adjusted [
              set cba-insulation-level 1
              set cba-position 4
              set cba-option   item 4 cba-1-gas]]

          if insulation-level = 2 [
            let cba-2-cost-untie (map [i -> i / 200000] cba-2-cost)
            let cba-2-gas-untie  (map + cba-2-cost-untie cba-2-gas)
            let cba-2-gas-min     min cba-2-gas-untie ;no emissions, lowest cost-option
            let cba-2-gas-min-position position cba-2-gas-min cba-2-gas-untie
            let cba-1-gas-adjusted item 4 cba-1-gas + item 4 cba-1-cost / 200000
            set cba-option min (list cba-2-gas-min cba-1-gas-adjusted)

            if member? cba-option cba-2-gas-untie [
              set cba-insulation-level "No change"
              set cba-position cba-2-gas-min-position
              set cba-option   item cba-position cba-2-gas]

            if  cba-option = cba-1-gas-adjusted [
              set cba-insulation-level 1
              set cba-position 4
              set cba-option   item 4 cba-1-gas]]

          if insulation-level = 1 [
            let cba-1-cost-untie (map [i -> i / 200000] cba-1-cost)
            let cba-1-gas-untie  (map + cba-1-cost-untie cba-1-gas)
            let cba-1-gas-min     min cba-1-gas-untie ;no emissions, lowest cost-option
            let cba-1-gas-min-position position cba-1-gas-min cba-1-gas-untie
            set cba-option cba-1-gas-min

            if member? cba-option cba-1-cost-untie [
              set cba-insulation-level "No change"
              set cba-position cba-1-gas-min-position
              set cba-option   item cba-position cba-1-gas]]]


        if cba-position = 0 [
          set cba-newHtech "CHP"]
        if cba-position = 1 [
          set cba-newHtech "FullyE"]
        if cba-position = 2 [
          set cba-newHtech "HPair"]
        if cba-position = 3 [
          set cba-newHtech "HPgeo"]
        if cba-position = 4 [
          set cba-newHtech "No change"]]

        ]
      ]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;::;   HOUSEHOLDS INVEST   ;;;;;;;;;;;;::
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



to households-invest

  ask households [

    if invest? <= 0 [

      ;record their information for the previous year: which insulation level they had and which technology
      set insulation-level-historical lput insulation-level insulation-level-historical
      set htechs-historical-name      lput ([name] of one-of htechs with [householdowner = myself]) htechs-historical-name
      set htechs-historical-self      lput ([self] of one-of htechs with [householdowner = myself]) htechs-historical-self
      set htechs-historical-capacity  lput ([capacity] of one-of htechs with [householdowner = myself]) htechs-historical-capacity

      ;UPDATE THEIR INSULATION
      ;change the level of insulation in their properties, and the capital costs
      if cba-insulation-level != "No change" [  ;if there is a change in insulation

        if insulation-level > cba-insulation-level [ ;if the current insulation coefficient is bigger than the option taken (households never choose a worse level of insulation as it would come with more expenses

          set invest? HRZ  ;capacity to invest gets restarted, meaning that they have to wait HRZ years before being able to invest again

          if insulation-level = 3 [   ;if the current insulation is 3

            if cba-insulation-level = 2 [  ;if the new insulation level that has been selected in the "households select investment" procedure is 2
              let in-po position cba-insulation-level item 0 inPlan-newinsulation-level  ;stores the position of the chosen insulation to use as a reference later
              set cashflow cashflow - item 0 item in-po inPlan-CapEx  ;uses the stored position to record the capital costs
              set expenses-yearly expenses-yearly + item 0 item in-po inPlan-CapEx
              set insulation-level cba-insulation-level] ; updates insulation-level

            if cba-insulation-level = 1 [
              let in-po position cba-insulation-level item 0 inPlan-newinsulation-level
              set cashflow cashflow - item 0 item in-po inPlan-CapEx
              set expenses-yearly expenses-yearly + item 0 item in-po inPlan-CapEx
              set insulation-level cba-insulation-level]]

          if insulation-level = 2 [
            if cba-insulation-level = 1 [
              let in-po position cba-insulation-level item 1 inPlan-newinsulation-level
              set cashflow cashflow - item 1 item in-po inPlan-CapEx
              set expenses-yearly expenses-yearly + item 0 item in-po inPlan-CapEx
              set insulation-level cba-insulation-level]]]]


      ;UPDATE THEIR HTECHS
      ;kill old technology, hatch new technology, update money

      if cba-newhtech != "No change" [

        set invest? HRZ

        ask htechs with [householdowner = myself] [
          set Active 0
          die]


        hatch-hTechs 1 [

          let cba-position2 [cba-position] of myself
          set householdOwner myself
          set name     item cba-position2 item 0 Htech-name
          set age      0
          set e-source item cba-position2 item 0 Htech-Esource
          set nH       item cba-position2 item 0 Htech-nH
          set nE       item cba-position2 item 0 Htech-nE
          set ngconsumed 0

          ;below for setting the capacity of the new technology
          let insulation-level2 [insulation-level] of myself
          ifelse insulation-level2 = 3 [
            set Capacity capacity-insulation-level-3][
            ifelse insulation-level2 = 2 [
              set Capacity item 0 item 0 inPlan-Capacity][
              set Capacity item 1 item 0 inPlan-Capacity]]
          set Active 1

          ;below for setting the expenses that the technology generates: the one time CapEx and the yearly OpEx
          set CapEx    item cba-position2 item 0  Htech-CapEx * Capacity
          set OpEx     item cba-position2 item 0  Htech-OpEx  * Capacity]


        set cashflow cashflow - [CapEx] of one-of htechs with [householdOwner = myself]
        set expenses-yearly expenses-yearly + [CapEx] of one-of htechs with [householdOwner = myself]
        set htechbought [self] of htechs with [householdOwner = myself]
      ]
    ]
  ]

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;:;;;;;;;;;;   STATE   ;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to state

  set total-expenses (sum [cashflow] of households * -1) / 1000 ;this tracks expenses in thousands of Euros
  set total-yearly-expenses   (sum [expenses-yearly] of households) / 1000  ;this tracks expenses in thousands of Euros
  set total-gas (sum [NGconsumed] of households) / 1000
  set total-yearly-gas (sum [NGconsumed-yearly] of households) / 1000  ;this tracks gas in MWh

  set in-low count households with [insulation-level = 3]
  set in-med count households with [insulation-level = 2]
  set in-hgh count households with [insulation-level = 1]

  set NGboiler count htechs with [name = "NG-boiler"]
  set CHP count htechs with [name = "CHP" and capacity <= 15]
  set radiators count htechs with [name = "FullyE" and capacity <= 15]
  set HPair count htechs with [name = "HPair"]
  set HPgeo count htechs with [name = "HPgeo"]

end
@#$#@#$#@
GRAPHICS-WINDOW
7
12
444
450
-1
-1
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
116
459
222
507
Go
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
11
460
108
507
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
231
461
341
506
Year
time
17
1
11

PLOT
11
623
384
788
Type of heat technology
Year
No of households
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"smaller NG boiler" 1.0 0 -16777216 true "" "plot count htechs with [name = \"NG-boiler\"]"
"smaller CHP" 1.0 0 -7500403 true "" "plot count htechs with [name = \"CHP\" and capacity <= 15]"
"smaller electric" 1.0 0 -2674135 true "" "plot count htechs with [name = \"FullyE\" and capacity <= 15]"
"smaller aerial HP" 1.0 0 -955883 true "" "plot count htechs with [name = \"HPair\"]"
"smaller geothermal HP" 1.0 0 -6459832 true "" "plot count htechs with [name = \"HPgeo\"]"
"building CHP" 1.0 0 -1184463 true "" "plot count htechs with [name = \"CHP\" and capacity > 15]"
"building electric" 1.0 0 -10899396 true "" "plot count htechs with [name = \"FullyE\" and capacity > 15]"

PLOT
392
623
751
788
Insulation level
Year
No of households
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Low insulation" 1.0 0 -16777216 true "" "plot count households with [insulation-level = 3]"
"Med insulation" 1.0 0 -7500403 true "" "plot count households with [insulation-level = 2]"
"Quasi passive" 1.0 0 -2674135 true "" "plot count households with [insulation-level = 1]"

SLIDER
113
547
225
580
AAI%
AAI%
0
1
0.0
.5
1
Frac
HORIZONTAL

SLIDER
11
510
109
543
dgp
dgp
-0.04
0.04
-0.025
.04
1
Frac
HORIZONTAL

SLIDER
230
547
340
580
dep
dep
-.04
.04
0.04
.04
1
Frac
HORIZONTAL

SLIDER
114
584
227
617
all-HRZ
all-HRZ
0
50
19.0
1
1
years
HORIZONTAL

SLIDER
10
546
106
579
popESF
popESF
1
7
3.0
1
1
NIL
HORIZONTAL

PLOT
482
214
724
379
Natural gas consumed
Year
MWh
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot total-gas"

PLOT
482
385
724
548
Total costs
Year
Thousands of Euros
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot total-expenses"

@#$#@#$#@
## WHAT IS IT?

This agent-based model is described in the publication below. Please see the publication for additional details. 

Nava Guerrero, G. D. C., Korevaar, G., Hansen, H. H., & Lukszo, Z. (2019). Agent-based modeling of a thermal energy transition in the built environment. Energies, 12(5), 856. DOI: https://doi.org/10.3390/en12050856 

This model is a simplified representation of a neighbourhood in which households have natural gas boilers and consider alternative heating systems and/or improvements in their insulation.

## HOW IT WORKS

Agents decide whether to change their technologies and consider factors such as "environment", "finances", and "society". They consider specific time horizons in financial calculations; they may be able to compare combinations of insulation levels and heating systems, or they may only be able to compare one option at a time. 

## HOW TO USE IT

Use the sliders in the Interface to adjust 5 parameters:

dep: change in electricity price.
dqp: change in natural gas price.
all-HRZ: horizon of financial calculations.
popESF: whether households consider "environment", "finances", or "society".
AAI%: percentage of households who can compare compared investments.


## INPUT DATA

See publication for input data: 

Nava Guerrero, G. D. C., Korevaar, G., Hansen, H. H., & Lukszo, Z. (2019). Agent-based modeling of a thermal energy transition in the built environment. Energies, 12(5), 856. DOI: https://doi.org/10.3390/en12050856 

See .csv file with results from a simulation in the journal paper. The dataset is also available at: https://doi.org/10.4121/18865355


## RELATED MODELS

This agent-based model is the first of a set of three agent-based models that explore the heat transition in The Netherlands, by the same authors. All three models are available in the 4TU repository. 

Below, the list of journal papers and the links to the agent-based models in the 4TU repository.

1. Nava Guerrero, G. D. C., Korevaar, G., Hansen, H. H., & Lukszo, Z. (2019). Agent-based modeling of a thermal energy transition in the built environment. Energies, 12(5), 856. DOI of journal paper: https://doi.org/10.3390/en12050856 
DOI of agent-based model: https://doi.org/10.4121/18865367
DOI of simulation results: https://doi.org/10.4121/18865355


2. Nava-Guerrero, G.D.C., Hansen, H.H., Korevaar, G., & Lukszo, Z. (2021). The effect of group decisions in heat transitions: An agent-based approach. Energy Policy, 156. 
DOI of journal paper: https://doi.org/10.1016/j.enpol.2021.112306
DOI of agent-based model: https://doi.org/10.4121/18865415
DOI of simulation results: https://doi.org/10.4121/18865385


3. Nava Guerrero, G. D. C., Hansen, H. H., Korevaar, G., & Lukszo, Z. (2021). An agent-based exploration of the effect of multi-criteria decisions on complex socio-technical heat transitions. Applied Energy. 306(Part B). 
DOI of journal paper: https://doi.org/10.1016/j.apenergy.2021.118118
DOI of agent-based model: https://doi.org/10.4121/18865433
DOI of simulation results: https://doi.org/10.4121/18865406

## CREDITS AND REFERENCES

To cite this model, please use the following citation:

Nava Guerrero, G. D. C., Korevaar, G., Hansen, H. H., & Lukszo, Z. (2022). Agent-based model described in journal article "Agent-based modeling of a thermal energy transition in the built environment". Publisher of agent-based model: 4TU Repository. DOI of agent-based model: https://doi.org/10.4121/18865367.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Feb4 - SES&amp;4GDH 2019" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>total-expenses</metric>
    <metric>total-yearly-expenses</metric>
    <metric>total-gas</metric>
    <metric>total-yearly-gas</metric>
    <metric>NGboiler</metric>
    <metric>CHP</metric>
    <metric>radiators</metric>
    <metric>HPair</metric>
    <metric>Hpgeo</metric>
    <metric>in-low</metric>
    <metric>in-med</metric>
    <metric>in-hgh</metric>
    <enumeratedValueSet variable="dgp">
      <value value="-0.04"/>
      <value value="0"/>
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="AAI%">
      <value value="0"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="popESF">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
      <value value="5"/>
      <value value="6"/>
      <value value="7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dep">
      <value value="-0.04"/>
      <value value="0"/>
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="all-HRZ">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
      <value value="15"/>
      <value value="20"/>
      <value value="30"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
